==> vertx-rx-java2-4.4.4-sources.jar: io/vertx/reactivex/grpc/server/GrpcServerResponse.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.reactivex.grpc.server;

import io.vertx.reactivex.RxHelper;
import io.vertx.reactivex.ObservableHelper;
import io.vertx.reactivex.FlowableHelper;
import io.vertx.reactivex.impl.AsyncResultMaybe;
import io.vertx.reactivex.impl.AsyncResultSingle;
import io.vertx.reactivex.impl.AsyncResultCompletable;
import io.vertx.reactivex.WriteStreamObserver;
import io.vertx.reactivex.WriteStreamSubscriber;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.grpc.server.GrpcServerResponse.class)
public class GrpcServerResponse<Req,Resp> extends io.vertx.reactivex.grpc.common.GrpcWriteStream<Resp> {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GrpcServerResponse that = (GrpcServerResponse) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<GrpcServerResponse> __TYPE_ARG = new TypeArg<>(    obj -> new GrpcServerResponse((io.vertx.grpc.server.GrpcServerResponse) obj),
    GrpcServerResponse::getDelegate
  );

  private final io.vertx.grpc.server.GrpcServerResponse<Req,Resp> delegate;
  public final TypeArg<Req> __typeArg_0;
  public final TypeArg<Resp> __typeArg_1;
  
  public GrpcServerResponse(io.vertx.grpc.server.GrpcServerResponse delegate) {
    super(delegate);
    this.delegate = delegate;
    this.__typeArg_0 = TypeArg.unknown();    this.__typeArg_1 = TypeArg.unknown();  }

  public GrpcServerResponse(Object delegate, TypeArg<Req> typeArg_0, TypeArg<Resp> typeArg_1) {
    super((io.vertx.grpc.server.GrpcServerResponse)delegate);
    this.delegate = (io.vertx.grpc.server.GrpcServerResponse)delegate;
    this.__typeArg_0 = typeArg_0;
    this.__typeArg_1 = typeArg_1;
  }

  public io.vertx.grpc.server.GrpcServerResponse getDelegate() {
    return delegate;
  }

  private WriteStreamObserver<Resp> observer;
  private WriteStreamSubscriber<Resp> subscriber;

  public synchronized WriteStreamObserver<Resp> toObserver() {
    if (observer == null) {
      Function<Resp, Resp> conv = (Function<Resp, Resp>) __typeArg_0.unwrap;
      observer = RxHelper.toObserver(getDelegate(), conv);
    }
    return observer;
  }

  public synchronized WriteStreamSubscriber<Resp> toSubscriber() {
    if (subscriber == null) {
      Function<Resp, Resp> conv = (Function<Resp, Resp>) __typeArg_0.unwrap;
      subscriber = RxHelper.toSubscriber(getDelegate(), conv);
    }
    return subscriber;
  }


  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @param handler 
   */
  public void write(Resp data, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.lang.Void>> handler) { 
    delegate.write(__typeArg_1.<Resp>unwrap(data), handler);
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   */
  public void write(Resp data) {
    write(data, ar -> { });
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @return 
   */
  public io.reactivex.Completable rxWrite(Resp data) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      write(data, $handler);
    });
  }

  /**
   * Same as {@link io.vertx.reactivex.core.streams.WriteStream#end} but with an <code>handler</code> called when the operation completes
   * @param handler 
   */
  public void end(io.vertx.core.Handler<io.vertx.core.AsyncResult<java.lang.Void>> handler) { 
    delegate.end(handler);
  }

  /**
   * Same as {@link io.vertx.reactivex.core.streams.WriteStream#end} but with an <code>handler</code> called when the operation completes
   */
  public void end() {
    end(ar -> { });
  }

  /**
   * Same as {@link io.vertx.reactivex.core.streams.WriteStream#end} but with an <code>handler</code> called when the operation completes
   * @return 
   */
  public io.reactivex.Completable rxEnd() { 
    return AsyncResultCompletable.toCompletable($handler -> {
      end($handler);
    });
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @param handler 
   */
  public void end(Resp data, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.lang.Void>> handler) { 
    delegate.end(__typeArg_1.<Resp>unwrap(data), handler);
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   */
  public void end(Resp data) {
    end(data, ar -> { });
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @return 
   */
  public io.reactivex.Completable rxEnd(Resp data) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      end(data, $handler);
    });
  }

  /**
   * This will return <code>true</code> if there are more bytes in the write queue than the value set using {@link io.vertx.reactivex.grpc.server.GrpcServerResponse#setWriteQueueMaxSize}
   * @return <code>true</code> if write queue is full
   */
  public boolean writeQueueFull() { 
    boolean ret = delegate.writeQueueFull();
    return ret;
  }

  /**
   * Set the grpc status response
   * @param status the status
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> status(io.vertx.grpc.common.GrpcStatus status) { 
    delegate.status(status);
    return this;
  }

  /**
   * Set the grpc status response message
   * @param msg the message
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> statusMessage(java.lang.String msg) { 
    delegate.statusMessage(msg);
    return this;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> encoding(java.lang.String encoding) { 
    delegate.encoding(encoding);
    return this;
  }

  /**
   * @return the  to write metadata trailers
   */
  public io.vertx.reactivex.core.MultiMap trailers() { 
    io.vertx.reactivex.core.MultiMap ret = io.vertx.reactivex.core.MultiMap.newInstance((io.vertx.core.MultiMap)delegate.trailers());
    return ret;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> exceptionHandler(io.vertx.core.Handler<java.lang.Throwable> handler) { 
    delegate.exceptionHandler(handler);
    return this;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> setWriteQueueMaxSize(int maxSize) { 
    delegate.setWriteQueueMaxSize(maxSize);
    return this;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> drainHandler(io.vertx.core.Handler<java.lang.Void> handler) { 
    delegate.drainHandler(handler);
    return this;
  }

  public io.vertx.core.Future<java.lang.Void> send(Resp item) { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.send(__typeArg_1.<Resp>unwrap(item)).map(val -> val);
    return ret;
  }

  public io.reactivex.Completable rxSend(Resp item) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      send(item).onComplete($handler);
    });
  }

  public io.vertx.core.Future<java.lang.Void> send(io.vertx.reactivex.core.streams.ReadStream<Resp> body) { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.send(body.getDelegate()).map(val -> val);
    return ret;
  }

  public io.reactivex.Completable rxSend(io.vertx.reactivex.core.streams.ReadStream<Resp> body) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      send(body).onComplete($handler);
    });
  }

  public io.vertx.core.Future<java.lang.Void> send(io.reactivex.Flowable<Resp> body) { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.send(io.vertx.reactivex.impl.ReadStreamSubscriber.asReadStream(body, obj -> __typeArg_1.<Resp>unwrap(obj)).resume()).map(val -> val);
    return ret;
  }

  public io.reactivex.Completable rxSend(io.reactivex.Flowable<Resp> body) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      send(body).onComplete($handler);
    });
  }

  public static <Req,Resp> GrpcServerResponse<Req,Resp> newInstance(io.vertx.grpc.server.GrpcServerResponse arg) {
    return arg != null ? new GrpcServerResponse<Req,Resp>(arg) : null;
  }

  public static <Req,Resp> GrpcServerResponse<Req,Resp> newInstance(io.vertx.grpc.server.GrpcServerResponse arg, TypeArg<Req> __typeArg_Req, TypeArg<Resp> __typeArg_Resp) {
    return arg != null ? new GrpcServerResponse<Req,Resp>(arg, __typeArg_Req, __typeArg_Resp) : null;
  }

}

==> vertx-rx-java2-4.5.20-sources.jar: io/vertx/reactivex/grpc/server/GrpcServerResponse.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.reactivex.grpc.server;

import io.vertx.reactivex.RxHelper;
import io.vertx.reactivex.ObservableHelper;
import io.vertx.reactivex.FlowableHelper;
import io.vertx.reactivex.impl.AsyncResultMaybe;
import io.vertx.reactivex.impl.AsyncResultSingle;
import io.vertx.reactivex.impl.AsyncResultCompletable;
import io.vertx.reactivex.WriteStreamObserver;
import io.vertx.reactivex.WriteStreamSubscriber;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxDelegate;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.grpc.server.GrpcServerResponse.class)
public class GrpcServerResponse<Req,Resp> extends io.vertx.reactivex.grpc.common.GrpcWriteStream<Resp> implements RxDelegate {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GrpcServerResponse that = (GrpcServerResponse) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<GrpcServerResponse> __TYPE_ARG = new TypeArg<>(    obj -> new GrpcServerResponse((io.vertx.grpc.server.GrpcServerResponse) obj),
    GrpcServerResponse::getDelegate
  );

  private final io.vertx.grpc.server.GrpcServerResponse<Req,Resp> delegate;
  public final TypeArg<Req> __typeArg_0;
  public final TypeArg<Resp> __typeArg_1;
  
  public GrpcServerResponse(io.vertx.grpc.server.GrpcServerResponse delegate) {
    super(delegate);
    this.delegate = delegate;
    this.__typeArg_0 = TypeArg.unknown();    this.__typeArg_1 = TypeArg.unknown();  }

  public GrpcServerResponse(Object delegate, TypeArg<Req> typeArg_0, TypeArg<Resp> typeArg_1) {
    super((io.vertx.grpc.server.GrpcServerResponse)delegate);
    this.delegate = (io.vertx.grpc.server.GrpcServerResponse)delegate;
    this.__typeArg_0 = typeArg_0;
    this.__typeArg_1 = typeArg_1;
  }

  @Override 
  public io.vertx.grpc.server.GrpcServerResponse getDelegate() {
    return delegate;
  }

  private WriteStreamObserver<Resp> observer;
  private WriteStreamSubscriber<Resp> subscriber;

  public synchronized WriteStreamObserver<Resp> toObserver() {
    if (observer == null) {
      Function<Resp, Resp> conv = (Function<Resp, Resp>) __typeArg_0.unwrap;
      observer = RxHelper.toObserver(getDelegate(), conv);
    }
    return observer;
  }

  public synchronized WriteStreamSubscriber<Resp> toSubscriber() {
    if (subscriber == null) {
      Function<Resp, Resp> conv = (Function<Resp, Resp>) __typeArg_0.unwrap;
      subscriber = RxHelper.toSubscriber(getDelegate(), conv);
    }
    return subscriber;
  }


  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @param handler 
   */
  public void write(Resp data, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.lang.Void>> handler) { 
    delegate.write(__typeArg_1.<Resp>unwrap(data), handler);
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   */
  public void write(Resp data) {
    write(data, ar -> { });
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @return 
   */
  public io.reactivex.Completable rxWrite(Resp data) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      write(data, $handler);
    });
  }

  /**
   * Same as {@link io.vertx.reactivex.core.streams.WriteStream#end} but with an <code>handler</code> called when the operation completes
   * @param handler 
   */
  public void end(io.vertx.core.Handler<io.vertx.core.AsyncResult<java.lang.Void>> handler) { 
    delegate.end(handler);
  }

  /**
   * Same as {@link io.vertx.reactivex.core.streams.WriteStream#end} but with an <code>handler</code> called when the operation completes
   */
  public void end() {
    end(ar -> { });
  }

  /**
   * Same as {@link io.vertx.reactivex.core.streams.WriteStream#end} but with an <code>handler</code> called when the operation completes
   * @return 
   */
  public io.reactivex.Completable rxEnd() { 
    return AsyncResultCompletable.toCompletable($handler -> {
      end($handler);
    });
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @param handler 
   */
  public void end(Resp data, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.lang.Void>> handler) { 
    delegate.end(__typeArg_1.<Resp>unwrap(data), handler);
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   */
  public void end(Resp data) {
    end(data, ar -> { });
  }

  /**
   * Same as  but with an <code>handler</code> called when the operation completes
   * @param data 
   * @return 
   */
  public io.reactivex.Completable rxEnd(Resp data) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      end(data, $handler);
    });
  }

  /**
   * This will return <code>true</code> if there are more bytes in the write queue than the value set using {@link io.vertx.reactivex.grpc.server.GrpcServerResponse#setWriteQueueMaxSize}
   * @return <code>true</code> if write queue is full
   */
  public boolean writeQueueFull() { 
    boolean ret = delegate.writeQueueFull();
    return ret;
  }

  /**
   * Set the grpc status response
   * @param status the status
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> status(io.vertx.grpc.common.GrpcStatus status) { 
    delegate.status(status);
    return this;
  }

  /**
   * Set the grpc status response message
   * @param msg the message
   * @return a reference to this, so the API can be used fluently
   */
  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> statusMessage(java.lang.String msg) { 
    delegate.statusMessage(msg);
    return this;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> encoding(java.lang.String encoding) { 
    delegate.encoding(encoding);
    return this;
  }

  /**
   * @return the  to write metadata trailers
   */
  public io.vertx.reactivex.core.MultiMap trailers() { 
    io.vertx.reactivex.core.MultiMap ret = io.vertx.reactivex.core.MultiMap.newInstance((io.vertx.core.MultiMap)delegate.trailers());
    return ret;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> exceptionHandler(io.vertx.core.Handler<java.lang.Throwable> handler) { 
    delegate.exceptionHandler(handler);
    return this;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> setWriteQueueMaxSize(int maxSize) { 
    delegate.setWriteQueueMaxSize(maxSize);
    return this;
  }

  public io.vertx.reactivex.grpc.server.GrpcServerResponse<Req,Resp> drainHandler(io.vertx.core.Handler<java.lang.Void> handler) { 
    delegate.drainHandler(handler);
    return this;
  }

  /**
   * Send the response headers.
   * @return a future notified by the success or failure of the write
   */
  public io.vertx.core.Future<java.lang.Void> writeHead() { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.writeHead().map(val -> val);
    return ret;
  }

  /**
   * Send the response headers.
   * @return a future notified by the success or failure of the write
   */
  public io.reactivex.Completable rxWriteHead() { 
    return AsyncResultCompletable.toCompletable($handler -> {
      writeHead().onComplete($handler);
    });
  }

  public io.vertx.core.Future<java.lang.Void> send(Resp item) { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.send(__typeArg_1.<Resp>unwrap(item)).map(val -> val);
    return ret;
  }

  public io.reactivex.Completable rxSend(Resp item) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      send(item).onComplete($handler);
    });
  }

  public io.vertx.core.Future<java.lang.Void> send(io.vertx.reactivex.core.streams.ReadStream<Resp> body) { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.send(body.getDelegate()).map(val -> val);
    return ret;
  }

  public io.reactivex.Completable rxSend(io.vertx.reactivex.core.streams.ReadStream<Resp> body) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      send(body).onComplete($handler);
    });
  }

  public io.vertx.core.Future<java.lang.Void> send(io.reactivex.Flowable<Resp> body) { 
    io.vertx.core.Future<java.lang.Void> ret = delegate.send(io.vertx.reactivex.impl.ReadStreamSubscriber.asReadStream(body, obj -> __typeArg_1.<Resp>unwrap(obj)).resume()).map(val -> val);
    return ret;
  }

  public io.reactivex.Completable rxSend(io.reactivex.Flowable<Resp> body) { 
    return AsyncResultCompletable.toCompletable($handler -> {
      send(body).onComplete($handler);
    });
  }

  public static <Req,Resp> GrpcServerResponse<Req,Resp> newInstance(io.vertx.grpc.server.GrpcServerResponse arg) {
    return arg != null ? new GrpcServerResponse<Req,Resp>(arg) : null;
  }

  public static <Req,Resp> GrpcServerResponse<Req,Resp> newInstance(io.vertx.grpc.server.GrpcServerResponse arg, TypeArg<Req> __typeArg_Req, TypeArg<Resp> __typeArg_Resp) {
    return arg != null ? new GrpcServerResponse<Req,Resp>(arg, __typeArg_Req, __typeArg_Resp) : null;
  }

}
